@@ -326,7 +326,11 @@ void VocabularyView::slotEditPaste()
         QStringList lines = clipboard->text().split('\n');
         foreach(QString line, lines) {
             // split at tabs or semicolon:
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             m_model->appendEntry(new KEduVocExpression(line.split(QRegExp(QStringLiteral("[\t;]")), QString::KeepEmptyParts)));
+#else
+            m_model->appendEntry(new KEduVocExpression(line.split(QRegExp(QStringLiteral("[\t;]")), Qt::KeepEmptyParts)));
+#endif
         }
     }
 }
