@@ -70,7 +70,7 @@ X-KDE-PluginInfo-Author=Avgoustinos Kadis
 X-KDE-PluginInfo-Email=avgoustinos.kadis@kdemail.net
 X-KDE-PluginInfo-Name=parley_example_script
 X-KDE-PluginInfo-Version=1.1
-X-KDE-PluginInfo-Website=http://edu.kde.org/parley
+X-KDE-PluginInfo-Website=https://edu.kde.org/parley
 X-KDE-PluginInfo-Category=examples
 X-KDE-PluginInfo-License=GPL
 X-KDE-PluginInfo-EnabledByDefault=true
